import { CustomError } from 'ts-custom-error';
export declare class IntegrationError extends CustomError {
    code: string | undefined;
    status: number | undefined;
    retry?: boolean;
    constructor(message: string, code: string, status: number);
}
declare type RetryableStatusCodes = 408 | 423 | 429 | 500 | 502 | 503 | 504 | 505 | 506 | 507 | 508 | 509 | 510 | 511 | 598 | 599;
export declare class RetryableError extends CustomError {
    status: RetryableStatusCodes;
    code: CustomErrorCodes;
    constructor(message?: string, status?: RetryableStatusCodes);
}
export declare class InvalidAuthenticationError extends CustomError {
    status: number;
    code: string;
    constructor(message?: string, code?: CustomErrorCodes);
}
export declare class PayloadValidationError extends IntegrationError {
    constructor(message: string);
}
export declare class APIError extends IntegrationError {
    constructor(message: string, status: number);
}
export declare class SelfTimeoutError extends IntegrationError {
    constructor(message: string);
}
export declare enum HttpErrorCodes {
    CONTINUE = "CONTINUE",
    SWITCHING_PROTOCOLS = "SWITCHING_PROTOCOLS",
    PROCESSING = "PROCESSING",
    EARLY_HINTS = "EARLY_HINTS",
    OK = "OK",
    CREATED = "CREATED",
    ACCEPTED = "ACCEPTED",
    NON_AUTHORITATIVE_INFORMATION = "NON_AUTHORITATIVE_INFORMATION",
    NO_CONTENT = "NO_CONTENT",
    RESET_CONTENT = "RESET_CONTENT",
    PARTIAL_CONTENT = "PARTIAL_CONTENT",
    MULTI_STATUS = "MULTI_STATUS",
    ALREADY_REPORTED = "ALREADY_REPORTED",
    IM_USED = "IM_USED",
    MULTIPLE_CHOICES = "MULTIPLE_CHOICES",
    MOVED_PERMENANTLY = "MOVED_PERMENANTLY",
    FOUND = "FOUND",
    SEE_OTHER = "SEE_OTHER",
    NOT_MODIFIED = "NOT_MODIFIED",
    USE_PROXY = "USE_PROXY",
    SWITCH_PROXY = "SWITCH_PROXY",
    TEMPORARY_REDIRECT = "TEMPORARY_REDIRECT",
    PERMANENT_REDIRECT = "PERMANENT_REDIRECT",
    BAD_REQUEST = "BAD_REQUEST",
    UNAUTHORIZED = "UNAUTHORIZED",
    PAYMENT_REQUIRED = "PAYMENT_REQUIRED",
    FORBIDDEN = "FORBIDDEN",
    NOT_FOUND = "NOT_FOUND",
    METHOD_NOT_ALLOWED = "METHOD_NOT_ALLOWED",
    NOT_ACCEPTABLE = "NOT_ACCEPTABLE",
    PROXY_AUTHENTICATION_REQUIRED = "PROXY_AUTHENTICATION_REQUIRED",
    REQUEST_TIMEOUT = "REQUEST_TIMEOUT",
    CONFLICT = "CONFLICT",
    GONE = "GONE",
    LENGTH_REQUIRED = "LENGTH_REQUIRED",
    PRECONDITION_FAILED = "PRECONDITION_FAILED",
    PAYLOAD_TOO_LARGE = "PAYLOAD_TOO_LARGE",
    URI_TOO_LONG = "URI_TOO_LONG",
    UNSUPPORTED_MEDIA_TYPE = "UNSUPPORTED_MEDIA_TYPE",
    RANGE_NOT_SATISFIABLE = "RANGE_NOT_SATISFIABLE",
    EXPECTATION_FAILED = "EXPECTATION_FAILED",
    IM_A_TEAPOT = "IM_A_TEAPOT",
    MISDIRECTED_REQUEST = "MISDIRECTED_REQUEST",
    UNPROCESSABLE_ENTITY = "UNPROCESSABLE_ENTITY",
    LOCKED = "LOCKED",
    FAILED_DEPENDENCY = "FAILED_DEPENDENCY",
    TOO_EARLY = "TOO_EARLY",
    UPGRADE_REQUIRED = "UPGRADE_REQUIRED",
    PRECONDITION_REQUIRED = "PRECONDITION_REQUIRED",
    TOO_MANY_REQUESTS = "TOO_MANY_REQUESTS",
    REQUEST_HEADER_FIELDS_TOO_LARGE = "REQUEST_HEADER_FIELDS_TOO_LARGE",
    UNAVAILABLE_FOR_LEGAL_REASONS = "UNAVAILABLE_FOR_LEGAL_REASONS",
    INTERNAL_SERVER_ERROR = "INTERNAL_SERVER_ERROR",
    NOT_IMPLEMENTED = "NOT_IMPLEMENTED",
    BAD_GATEWAY = "BAD_GATEWAY",
    SERVICE_UNAVAILABLE = "SERVICE_UNAVAILABLE",
    GATEWAY_TIMEOUT = "GATEWAY_TIMEOUT",
    HTTP_VERSION_NOT_SUPPORTED = "HTTP_VERSION_NOT_SUPPORTED",
    VARIANT_ALSO_NEGOTIATES = "VARIANT_ALSO_NEGOTIATES",
    INSUFFICIENT_STORAGE = "INSUFFICIENT_STORAGE",
    LOOP_DETECTED = "LOOP_DETECTED",
    BANDWIDTH_LIMIT_EXCEEDED = "BANDWIDTH_LIMIT_EXCEEDED",
    NOT_EXTENDED = "NOT_EXTENDED",
    NETWORK_AUTHENTICATION_REQUIRED = "NETWORK_AUTHENTICATION_REQUIRED",
    SITE_IS_OVERLOADED = "SITE_IS_OVERLOADED"
}
export declare enum CustomErrorCodes {
    INVALID_AUTHENTICATION = "INVALID_AUTHENTICATION",
    PAYLOAD_VALIDATION_FAILED = "PAYLOAD_VALIDATION_FAILED",
    INVALID_CURRENCY_CODE = "INVALID_CURRENCY_CODE",
    RETRYABLE_ERROR = "RETRYABLE_ERROR",
    REFRESH_TOKEN_EXPIRED = "REFRESH_TOKEN_EXPIRED",
    OAUTH_REFRESH_FAILED = "OAUTH_REFRESH_FAILED",
    SELF_TIMEOUT = "SELF_TIMEOUT",
    UNKNOWN_ERROR = "UNKNOWN_ERROR"
}
export declare const ErrorCodes: {
    INVALID_AUTHENTICATION: CustomErrorCodes.INVALID_AUTHENTICATION;
    PAYLOAD_VALIDATION_FAILED: CustomErrorCodes.PAYLOAD_VALIDATION_FAILED;
    INVALID_CURRENCY_CODE: CustomErrorCodes.INVALID_CURRENCY_CODE;
    RETRYABLE_ERROR: CustomErrorCodes.RETRYABLE_ERROR;
    REFRESH_TOKEN_EXPIRED: CustomErrorCodes.REFRESH_TOKEN_EXPIRED;
    OAUTH_REFRESH_FAILED: CustomErrorCodes.OAUTH_REFRESH_FAILED;
    SELF_TIMEOUT: CustomErrorCodes.SELF_TIMEOUT;
    UNKNOWN_ERROR: CustomErrorCodes.UNKNOWN_ERROR;
    CONTINUE: HttpErrorCodes.CONTINUE;
    SWITCHING_PROTOCOLS: HttpErrorCodes.SWITCHING_PROTOCOLS;
    PROCESSING: HttpErrorCodes.PROCESSING;
    EARLY_HINTS: HttpErrorCodes.EARLY_HINTS;
    OK: HttpErrorCodes.OK;
    CREATED: HttpErrorCodes.CREATED;
    ACCEPTED: HttpErrorCodes.ACCEPTED;
    NON_AUTHORITATIVE_INFORMATION: HttpErrorCodes.NON_AUTHORITATIVE_INFORMATION;
    NO_CONTENT: HttpErrorCodes.NO_CONTENT;
    RESET_CONTENT: HttpErrorCodes.RESET_CONTENT;
    PARTIAL_CONTENT: HttpErrorCodes.PARTIAL_CONTENT;
    MULTI_STATUS: HttpErrorCodes.MULTI_STATUS;
    ALREADY_REPORTED: HttpErrorCodes.ALREADY_REPORTED;
    IM_USED: HttpErrorCodes.IM_USED;
    MULTIPLE_CHOICES: HttpErrorCodes.MULTIPLE_CHOICES;
    MOVED_PERMENANTLY: HttpErrorCodes.MOVED_PERMENANTLY;
    FOUND: HttpErrorCodes.FOUND;
    SEE_OTHER: HttpErrorCodes.SEE_OTHER;
    NOT_MODIFIED: HttpErrorCodes.NOT_MODIFIED;
    USE_PROXY: HttpErrorCodes.USE_PROXY;
    SWITCH_PROXY: HttpErrorCodes.SWITCH_PROXY;
    TEMPORARY_REDIRECT: HttpErrorCodes.TEMPORARY_REDIRECT;
    PERMANENT_REDIRECT: HttpErrorCodes.PERMANENT_REDIRECT;
    BAD_REQUEST: HttpErrorCodes.BAD_REQUEST;
    UNAUTHORIZED: HttpErrorCodes.UNAUTHORIZED;
    PAYMENT_REQUIRED: HttpErrorCodes.PAYMENT_REQUIRED;
    FORBIDDEN: HttpErrorCodes.FORBIDDEN;
    NOT_FOUND: HttpErrorCodes.NOT_FOUND;
    METHOD_NOT_ALLOWED: HttpErrorCodes.METHOD_NOT_ALLOWED;
    NOT_ACCEPTABLE: HttpErrorCodes.NOT_ACCEPTABLE;
    PROXY_AUTHENTICATION_REQUIRED: HttpErrorCodes.PROXY_AUTHENTICATION_REQUIRED;
    REQUEST_TIMEOUT: HttpErrorCodes.REQUEST_TIMEOUT;
    CONFLICT: HttpErrorCodes.CONFLICT;
    GONE: HttpErrorCodes.GONE;
    LENGTH_REQUIRED: HttpErrorCodes.LENGTH_REQUIRED;
    PRECONDITION_FAILED: HttpErrorCodes.PRECONDITION_FAILED;
    PAYLOAD_TOO_LARGE: HttpErrorCodes.PAYLOAD_TOO_LARGE;
    URI_TOO_LONG: HttpErrorCodes.URI_TOO_LONG;
    UNSUPPORTED_MEDIA_TYPE: HttpErrorCodes.UNSUPPORTED_MEDIA_TYPE;
    RANGE_NOT_SATISFIABLE: HttpErrorCodes.RANGE_NOT_SATISFIABLE;
    EXPECTATION_FAILED: HttpErrorCodes.EXPECTATION_FAILED;
    IM_A_TEAPOT: HttpErrorCodes.IM_A_TEAPOT;
    MISDIRECTED_REQUEST: HttpErrorCodes.MISDIRECTED_REQUEST;
    UNPROCESSABLE_ENTITY: HttpErrorCodes.UNPROCESSABLE_ENTITY;
    LOCKED: HttpErrorCodes.LOCKED;
    FAILED_DEPENDENCY: HttpErrorCodes.FAILED_DEPENDENCY;
    TOO_EARLY: HttpErrorCodes.TOO_EARLY;
    UPGRADE_REQUIRED: HttpErrorCodes.UPGRADE_REQUIRED;
    PRECONDITION_REQUIRED: HttpErrorCodes.PRECONDITION_REQUIRED;
    TOO_MANY_REQUESTS: HttpErrorCodes.TOO_MANY_REQUESTS;
    REQUEST_HEADER_FIELDS_TOO_LARGE: HttpErrorCodes.REQUEST_HEADER_FIELDS_TOO_LARGE;
    UNAVAILABLE_FOR_LEGAL_REASONS: HttpErrorCodes.UNAVAILABLE_FOR_LEGAL_REASONS;
    INTERNAL_SERVER_ERROR: HttpErrorCodes.INTERNAL_SERVER_ERROR;
    NOT_IMPLEMENTED: HttpErrorCodes.NOT_IMPLEMENTED;
    BAD_GATEWAY: HttpErrorCodes.BAD_GATEWAY;
    SERVICE_UNAVAILABLE: HttpErrorCodes.SERVICE_UNAVAILABLE;
    GATEWAY_TIMEOUT: HttpErrorCodes.GATEWAY_TIMEOUT;
    HTTP_VERSION_NOT_SUPPORTED: HttpErrorCodes.HTTP_VERSION_NOT_SUPPORTED;
    VARIANT_ALSO_NEGOTIATES: HttpErrorCodes.VARIANT_ALSO_NEGOTIATES;
    INSUFFICIENT_STORAGE: HttpErrorCodes.INSUFFICIENT_STORAGE;
    LOOP_DETECTED: HttpErrorCodes.LOOP_DETECTED;
    BANDWIDTH_LIMIT_EXCEEDED: HttpErrorCodes.BANDWIDTH_LIMIT_EXCEEDED;
    NOT_EXTENDED: HttpErrorCodes.NOT_EXTENDED;
    NETWORK_AUTHENTICATION_REQUIRED: HttpErrorCodes.NETWORK_AUTHENTICATION_REQUIRED;
    SITE_IS_OVERLOADED: HttpErrorCodes.SITE_IS_OVERLOADED;
};
export declare function getErrorCodeFromHttpStatus(status: number): keyof typeof ErrorCodes;
export declare enum MultiStatusErrorReporter {
    INTEGRATIONS = "INTEGRATIONS",
    DESTINATION = "DESTINATION"
}
export {};
